Calculates estimates at each successive wave of the sampling process
cumulative.estimate(rds.data, outcome.variable, est.func = RDS.II.estimates,
n.eval.points = 25, ...)An rds.data.frame
The outcome
A function taking rds.data and outcome.variable as parameters and returning an rds.weighted.estimate object
number of evaluation points to calculate the estimates at
additional parameters for est.func