get.seed.rid: Gets the recruiter id assosiated with the seeds
Description
Gets the recruiter id assosiated with the seeds
Usage
get.seed.rid(x, check.type = TRUE)
Arguments
check.type
if true, x is required to be of type rds.data.frame
Details
All seed nodes must have the same placeholder recruiter id.