print.summary.svyglm.RDS: Summarizing Generalized Linear Model Fits with Odds Ratios
Description
print.summary.svyglm.RDS is a version of print.summary.svyglm that
reports odds-ratios in place of coefficients in the summary table.
This only applies for the binomial family. Otherwise it is identical to
print.summary.svyglm.
The default in
print.summary.svyglm is to display the log-odds-ratios
and this displays the exponetiated from
and a 95
p-values are still displayed.
Usage
# S3 method for summary.svyglm.RDS
print(
x,
digits = max(3, getOption("digits") - 3),
symbolic.cor = x$symbolic.cor,
signif.stars = getOption("show.signif.stars"),
...
)Arguments
- x
an object of class "summary.svyglm.RDS", usually, a result of a
call to RDS::summary.svyglm.
- digits
the number of significant digits to use when printing.
- symbolic.cor
logical. If TRUE, print the correlations in a
symbolic form (see symnum) rather than as numbers.
- signif.stars
logical. If TRUE, ‘significance stars’ are
printed for each coefficient.
- ...
further arguments passed to or from other methods.
Examples
Run this code
## For examples see example(svyglm)
Run the code above in your browser using DataLab