This function sets the class of the control list, with the default being the name of the calling function.
set.control.class(myname = { sc <- sys.calls()
as.character(sc[[length(sc) - 1]][[1]]) }, control = get("control", pos =
parent.frame()))Name of the class to set. Defaults to the name of the calling function.
Control list. Defaults to the control variable in the
calling function.
The control list with class set.
check.control.class, print.control.list